#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide
version:              2.3.0.0
visibility:           public
id:                   ghcide-2.3.0.0-FhAbwsYEp6gAQgAB6C5VjW
key:                  ghcide-2.3.0.0-FhAbwsYEp6gAQgAB6C5VjW
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2020
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             The core of an IDE
description:          A library for building Haskell IDE'\''s on top of the GHC API.
category:             Development
abi:                  8fa0ac59748eb0113beb678992fe013c
exposed:              True
exposed-modules:
    Control.Concurrent.Strict Development.IDE
    Development.IDE.Core.Actions Development.IDE.Core.Compile
    Development.IDE.Core.Debouncer Development.IDE.Core.FileStore
    Development.IDE.Core.FileUtils
    Development.IDE.Core.IdeConfiguration
    Development.IDE.Core.OfInterest Development.IDE.Core.PluginUtils
    Development.IDE.Core.PositionMapping
    Development.IDE.Core.Preprocessor
    Development.IDE.Core.ProgressReporting
    Development.IDE.Core.RuleTypes Development.IDE.Core.Rules
    Development.IDE.Core.Service Development.IDE.Core.Shake
    Development.IDE.Core.Tracing Development.IDE.Core.UseStale
    Development.IDE.GHC.Compat Development.IDE.GHC.Compat.Core
    Development.IDE.GHC.Compat.Env Development.IDE.GHC.Compat.Iface
    Development.IDE.GHC.Compat.Logger
    Development.IDE.GHC.Compat.Outputable
    Development.IDE.GHC.Compat.Parser
    Development.IDE.GHC.Compat.Plugins Development.IDE.GHC.Compat.Units
    Development.IDE.GHC.Compat.Util Development.IDE.GHC.CoreFile
    Development.IDE.GHC.Error Development.IDE.GHC.Orphans
    Development.IDE.GHC.Util
    Development.IDE.Import.DependencyInformation
    Development.IDE.Import.FindImports
    Development.IDE.LSP.HoverDefinition
    Development.IDE.LSP.LanguageServer
    Development.IDE.LSP.Notifications Development.IDE.LSP.Outline
    Development.IDE.LSP.Server Development.IDE.Main
    Development.IDE.Main.HeapStats Development.IDE.Monitoring.EKG
    Development.IDE.Monitoring.OpenTelemetry Development.IDE.Plugin
    Development.IDE.Plugin.Completions
    Development.IDE.Plugin.Completions.Types Development.IDE.Plugin.HLS
    Development.IDE.Plugin.HLS.GhcIde Development.IDE.Plugin.Test
    Development.IDE.Plugin.TypeLenses Development.IDE.Session
    Development.IDE.Session.Diagnostics Development.IDE.Spans.AtPoint
    Development.IDE.Spans.Common Development.IDE.Spans.Documentation
    Development.IDE.Spans.LocalBindings Development.IDE.Spans.Pragmas
    Development.IDE.Types.Diagnostics Development.IDE.Types.Exports
    Development.IDE.Types.HscEnvEq Development.IDE.Types.KnownTargets
    Development.IDE.Types.Location Development.IDE.Types.Monitoring
    Development.IDE.Types.Options Development.IDE.Types.Shake
    Generics.SYB.GHC Text.Fuzzy.Parallel

hidden-modules:
    Development.IDE.Core.FileExists Development.IDE.GHC.CPP
    Development.IDE.GHC.Warnings
    Development.IDE.Plugin.Completions.Logic
    Development.IDE.Session.VersionCheck Development.IDE.Types.Action

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide
hs-libraries:         HSghcide-2.3.0.0-FhAbwsYEp6gAQgAB6C5VjW
depends:
    Diff-0.5-E1YfkK2HLk2KN6A8Bj7OS6 Glob-0.10.2-2WGrYk7k4aO9R55WfcllyF
    aeson-2.2.2.0-3wIqYzgVLxh1lGuh6CHfOQ array-0.5.6.0
    async-2.2.6-1uwD9YLU3T8L6PSEM5z6Gb base-4.18.2.1
    base16-bytestring-1.0.2.0-9LegNGgW8bg9FiwGbqOsIu binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-5z8pg5dkh9iJJTZAXWxvrE
    co-log-core-0.3.2.6-JDppXlNsarlHU0BOTpvaw5 containers-0.6.7
    cryptohash-sha1-0.11.101.0-Ioa2Fa9ONDZHgHwhkCMAcC
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz deepseq-1.4.8.1
    dependent-map-0.4.0.1-2KyaQL4LpP4MEIAPpFQvu
    dependent-sum-0.7.2.0-A1MeA2dkjFZFs6moWkQKRx directory-1.3.8.5
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    enummapset-0.7.3.0-6tXjKECm7w6F2T1iTP9IhL exceptions-0.10.7
    extra-1.7.16-KrpFpNhh5BQELeEbiAlFs2 filepath-1.4.300.1
    fingertree-0.1.6.3-1UCdRFFjlcS66fQmvu9t3D
    focus-1.0.3.2-F9LvlLfdRd2LptQzQRApRj ghc-9.6.6 ghc-boot-9.6.6
    ghc-boot-th-9.6.6 ghc-check-0.5.0.8-GIPjKh6C4CdEWH8Fik1r7d
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    ghc-trace-events-0.1.2.10-H26I0MYftT2GE85bySiIsN
    haddock-library-1.11.0-7J0BEhqzsva3MStHK54xVb
    hashable-1.4.7.0-LW11JqjzVD83xeTPITysTC
    hie-bios-0.12.0-2vuwK8Vqse85bxWREYCnSA
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    hiedb-0.4.3.0-9iU4NEc2ZdVCjyqjddOki7
    hls-graph-2.3.0.0-KobRHxNrtwkHIxNFmJfkC4
    hls-plugin-api-2.3.0.0-HoObs2qHfNKC106GqibI71
    implicit-hie-0.1.4.0-2wG4s3rf97d6wUjrAgi7S6
    implicit-hie-cradle-0.5.0.1-2GejCwcQhml3uCza9oDWeW
    lens-5.3.4-GdOistvs0Ub2JwuPi3uyv5
    list-t-1.0.5.7-HUolN9lPelH59LXN2KCa3E
    lsp-2.2.0.0-KGqb1yHTwPvBLMtVxTPYxl
    lsp-types-2.0.2.0-JpeXDU4gXlQBh5FfEiQFNp mtl-2.3.1
    opentelemetry-0.8.0-HLM0AkKHsOt6yxoIYG3vPG
    optparse-applicative-0.18.1.0-Drsi2gM4wlG4ppHqpHKUIr
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD
    prettyprinter-1.7.1-K33PLtU9PMb1Pvd3LZfaWw
    prettyprinter-ansi-terminal-1.1.4-Li4HQXtkWRIBaoveuj8BqF
    random-1.2.1.3-F4yImuU8Eln1YUMUzrSOOB
    regex-tdfa-1.3.2.5-EMaUzDKttstEI5BfFz11ci
    row-types-1.0.1.2-3NiU80FgncRCgFsly4cXZr
    safe-exceptions-0.1.7.4-HWCEItuykIj9L5YUgdbaCI
    sorted-list-0.2.3.1-8dfMOTPgsDsCV1I1IkPlxS
    sqlite-simple-0.4.19.0-GqBEtNkAOdsCtQnTMqMwKt stm-2.5.1.0
    stm-containers-1.2.1.1-2ZvKhFj7MdL5230YglMTU9
    syb-0.7.3-45RHZbqQsU9HukQlnlXSjw text-2.0.2
    text-rope-0.3-7ExQ13EVTj63IntzHLQAYB time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-48sGHGhS3Nb9ygO7gybAdR
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-HCJacsgu3yzJSt2gCXir1U
    vector-0.13.2.0-5aTe1V6fRGRBDLXlEcUVda

haddock-interfaces:   /usr/share/doc/haskell-ghcide/html/ghcide.haddock
haddock-html:         /usr/share/doc/haskell-ghcide/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

